==> OOo_3.0.0_src_extensions.tar.bz2: core/source/org/jfree/report/modules/factories/report/flow/AttributeExpressionReadHandler.java <==
/**
 * ========================================
 * JFreeReport : a free Java report library
 * ========================================
 *
 * Project Info:  http://reporting.pentaho.org/
 *
 * (C) Copyright 2000-2007, by Object Refinery Limited, Pentaho Corporation and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 *
 * ------------
 * $Id: AttributeExpressionReadHandler.java 3525 2007-10-16 11:43:48Z tmorgner $
 * ------------
 * (C) Copyright 2000-2005, by Object Refinery Limited.
 * (C) Copyright 2005-2007, by Pentaho Corporation.
 */
package org.jfree.report.modules.factories.report.flow;

import org.jfree.xmlns.parser.ParseException;
import org.jfree.xmlns.parser.StringReadHandler;
import org.jfree.xmlns.parser.XmlReadHandler;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

/**
 * Creation-Date: 09.04.2006, 13:40:08
 *
 * @author Thomas Morgner
 */
public class AttributeExpressionReadHandler
        extends AbstractExpressionReadHandler
{
  private StringReadHandler nameReadHandler;
  private StringReadHandler namespaceUriReadHandler;
  private String attributeName;
  private String namespace;

  public AttributeExpressionReadHandler()
  {
  }

  /**
   * Returns the handler for a child element.
   *
   * @param tagName the tag name.
   * @param atts    the attributes.
   * @return the handler or null, if the tagname is invalid.
   * @throws SAXException       if there is a parsing error.
   */
  protected XmlReadHandler getHandlerForChild(final String uri,
                                              final String tagName,
                                              final Attributes atts)
          throws SAXException
  {
    if (isSameNamespace(uri) == false)
    {
      return null;
    }
    if ("attribute-name".equals(tagName))
    {
      nameReadHandler = new StringReadHandler();
      return nameReadHandler;
    }
    if ("attribute-namespace-uri".equals(tagName))
    {
      namespaceUriReadHandler = new StringReadHandler();
      return namespaceUriReadHandler;
    }
    return super.getHandlerForChild(uri, tagName, atts);
  }

  /**
   * Done parsing.
   *
   * @throws SAXException       if there is a parsing error.
   */
  protected void doneParsing() throws SAXException
  {
    super.doneParsing();
    if (nameReadHandler == null)
    {
      throw new ParseException
          ("Required element 'attribute-name' is missing.", getLocator());
    }

    attributeName = nameReadHandler.getResult();

    if (namespaceUriReadHandler != null)
    {
      namespace = namespaceUriReadHandler.getResult();
    }
    if (namespace == null)
    {
      namespace = getNamespace();
    }

  }

  public String getNamespace()
  {
    return namespace;
  }

  public String getAttributeName()
  {
    return attributeName;
  }
}

==> OOo_3.2.1_src_extensions.tar.bz2: core/source/org/jfree/report/modules/factories/report/flow/AttributeExpressionReadHandler.java <==
/**
 * ========================================
 * JFreeReport : a free Java report library
 * ========================================
 *
 * Project Info:  http://reporting.pentaho.org/
 *
 * (C) Copyright 2000-2007, by Object Refinery Limited, Pentaho Corporation and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 *
 * ------------
 * $Id: AttributeExpressionReadHandler.java 6659 2008-12-02 15:35:06Z tmorgner $
 * ------------
 * (C) Copyright 2000-2005, by Object Refinery Limited.
 * (C) Copyright 2005-2007, by Pentaho Corporation.
 */
package org.jfree.report.modules.factories.report.flow;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.pentaho.reporting.libraries.xmlns.parser.StringReadHandler;
import org.pentaho.reporting.libraries.xmlns.parser.XmlReadHandler;
import org.pentaho.reporting.libraries.xmlns.parser.ParseException;

/**
 * Creation-Date: 09.04.2006, 13:40:08
 *
 * @author Thomas Morgner
 */
public class AttributeExpressionReadHandler
        extends AbstractExpressionReadHandler
{
  private StringReadHandler nameReadHandler;
  private StringReadHandler namespaceUriReadHandler;
  private String attributeName;
  private String namespace;

  public AttributeExpressionReadHandler()
  {
  }

  /**
   * Returns the handler for a child element.
   *
   * @param tagName the tag name.
   * @param atts    the attributes.
   * @return the handler or null, if the tagname is invalid.
   * @throws SAXException       if there is a parsing error.
   */
  protected XmlReadHandler getHandlerForChild(final String uri,
                                              final String tagName,
                                              final Attributes atts)
          throws SAXException
  {
    if (isSameNamespace(uri) == false)
    {
      return null;
    }
    if (tagName.equals("attribute-name"))
    {
      nameReadHandler = new StringReadHandler();
      return nameReadHandler;
    }
    if (tagName.equals("attribute-namespace-uri"))
    {
      namespaceUriReadHandler = new StringReadHandler();
      return namespaceUriReadHandler;
    }
    return super.getHandlerForChild(uri, tagName, atts);
  }

  /**
   * Done parsing.
   *
   * @throws SAXException       if there is a parsing error.
   */
  protected void doneParsing() throws SAXException
  {
    super.doneParsing();
    if (nameReadHandler == null)
    {
      throw new ParseException
          ("Required element 'attribute-name' is missing.", getLocator());
    }

    attributeName = nameReadHandler.getResult();

    if (namespaceUriReadHandler != null)
    {
      namespace = namespaceUriReadHandler.getResult();
    }
    if (namespace == null)
    {
      namespace = getNamespace();
    }

  }

  public String getNamespace()
  {
    return namespace;
  }

  public String getAttributeName()
  {
    return attributeName;
  }
}
